@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2022 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -238,7 +238,6 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
 {
   qApp->setWindowIcon(prefsIcon("ipe"));
   QMainWindow::setAttribute(Qt::WA_DeleteOnClose);
-  qApp->setAttribute(Qt::AA_UseHighDpiPixmaps);
   setDockOptions(AnimatedDocks); // do not allow stacking properties and layers
 
   Canvas *canvas = new Canvas(this);
@@ -255,7 +254,7 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
   set_toolbar_size(iObjectTools, iToolbarScale);
 
   iActionMap = new QSignalMapper(this);
-  connect(iActionMap, SIGNAL(mapped(const QString &)),
+  connect(iActionMap, SIGNAL(mappedString(const QString &)),
 	  SLOT(qAction(const QString &)));
 
   iModeActionGroup = new QActionGroup(this);
@@ -381,7 +380,7 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
   lo->setSizeConstraint(QLayout::SetFixedSize);
   QButtonGroup *bg = new QButtonGroup(wg);
   bg->setExclusive(false);
-  connect(bg, SIGNAL(buttonClicked(int)), this, SLOT(absoluteButton(int)));
+  connect(bg, SIGNAL(idClicked(int)), this, SLOT(absoluteButton(int)));
   iButton[EUiMarkShape] = nullptr;   // no such buttons
   iButton[EUiDashStyle] = nullptr;
   /* enum { EUiStroke, EUiFill, EUiPen, EUiDashStyle,
@@ -444,7 +443,7 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
   iSelector[EUiGridSize]->setToolTip("Grid size");
   iSelector[EUiAngleSize]->setToolTip("Angle for angular snap");
 
-  connect(comboMap, SIGNAL(mapped(int)), this, SLOT(comboSelector(int)));
+  connect(comboMap, SIGNAL(mappedInt(int)), this, SLOT(comboSelector(int)));
 
   iPathView = new PathView(uiscale(100));
   connect(iPathView, SIGNAL(activated(String)), SLOT(action(String)));
@@ -769,7 +768,7 @@ void AppUi::setBookmarks(int no, const String *s)
   for (int i = 0; i < no; ++i) {
     QListWidgetItem *item = new QListWidgetItem(QIpe(s[i]));
     if (s[i][0] == ' ')
-      item->setTextColor(Qt::blue);
+      item->setForeground(Qt::blue);
     iBookmarks->addItem(item);
   }
 }
@@ -798,8 +797,7 @@ void AppUi::setToolVisible(int m, bool vis)
 
 void AppUi::setZoom(double zoom)
 {
-  QString s;
-  s.sprintf("(%dppi)", int(72.0 * zoom));
+  QString s = QString("(%1ppi)").arg(int(72.0 * zoom));
   iResolution->setText(s);
   iCanvas->setZoom(zoom);
 }
