@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -237,7 +237,7 @@ static bool applyPngPrediction(Buffer &data, int width, int height, int componen
   return true;
 }
 
-static void drawImage(cairo_t *cr, const PdfDict *d, const PdfResourceBase *r, double opacity)
+static void drawImage(cairo_t *cr, const PdfDict *d, const PdfResourceBase *r, double opacity, bool filterBest)
 {
   // ipeDebug("Image: %s", d->dictRepr().z());
   int width = d->getInteger("Width");
@@ -351,7 +351,7 @@ static void drawImage(cairo_t *cr, const PdfDict *d, const PdfResourceBase *r, d
   Matrix tf = Matrix(1.0 / width, 0.0, 0.0, -1.0 / height, 0.0, 1.0);
   cairoTransform(cr, tf);
   cairo_set_source_surface(cr, image, 0, 0);
-  cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_GOOD);
+  cairo_pattern_set_filter(cairo_get_source(cr), filterBest ? CAIRO_FILTER_BEST : CAIRO_FILTER_GOOD);
   cairo_paint_with_alpha(cr, opacity);
   cairo_restore(cr);
 }
@@ -369,8 +369,9 @@ static void drawImage(cairo_t *cr, const PdfDict *d, const PdfResourceBase *r, d
 /*! \a zoom one means 72 pixels per inch.  Set \a pretty to true
   to avoid drawing text without Latex. */
 CairoPainter::CairoPainter(const Cascade *sheet, Fonts *fonts,
-			   cairo_t *cc, double zoom, bool pretty)
-  : Painter(sheet), iFonts(fonts), iCairo(cc), iZoom(zoom), iPretty(pretty), iType3Font(false)
+			   cairo_t *cc, double zoom, bool pretty, bool filterBest)
+  : Painter(sheet), iFonts(fonts), iCairo(cc), iZoom(zoom),
+    iPretty(pretty), iFilterBest(filterBest), iType3Font(false)
 {
   iDimmed = false;
 }
@@ -573,7 +574,7 @@ void CairoPainter::doDrawPath(TPathMode mode)
       std::vector<double> dashes;
       double offset;
       dashStyle(dashes, offset);
-      cairo_set_dash(iCairo, &dashes[0], dashes.size(), offset);
+      cairo_set_dash(iCairo, dashes.data(), dashes.size(), offset);
     }
     cairo_stroke(iCairo);
   }
@@ -604,7 +605,8 @@ void CairoPainter::doDrawBitmap(Bitmap bitmap)
 				0.0, 1.0);
   cairoTransform(iCairo, tf);
   cairo_set_source_surface(iCairo, image, 0, 0);
-  cairo_pattern_set_filter(cairo_get_source(iCairo), CAIRO_FILTER_GOOD);
+  cairo_pattern_set_filter(cairo_get_source(iCairo),
+			   iFilterBest ? CAIRO_FILTER_BEST : CAIRO_FILTER_GOOD);
   cairo_paint_with_alpha(iCairo, opacity().toDouble());
   cairo_restore(iCairo);
 }
@@ -962,7 +964,7 @@ void CairoPainter::opd()
     dashes.emplace_back(obj->number()->value());
   }
   double offset = iArgs[1]->number()->value();
-  cairo_set_dash(iCairo, &dashes[0], dashes.size(), offset);
+  cairo_set_dash(iCairo, dashes.data(), dashes.size(), offset);
 }
 
 void CairoPainter::opi()
@@ -1059,7 +1061,7 @@ void CairoPainter::opDo()
     execute(xf, xf);
     cairo_restore(iCairo);
   } else if (subtype == "Image") {
-    drawImage(iCairo, xf, iFonts->resources(), iPdfState.back().iFillOpacity);
+    drawImage(iCairo, xf, iFonts->resources(), iPdfState.back().iFillOpacity, iFilterBest);
   } else
     ipeDebug("Do operator with unsupported XObject subtype %s", subtype.z());
 }
@@ -1216,7 +1218,7 @@ void CairoPainter::createPattern()
 	cairo_save(cc);
 	cairo_translate(cc, -dx * width, -dy * height);
 	cairo_scale(cc, xscale, yscale);
-	CairoPainter painter(iCascade, iFonts, cc, 1.0, false);
+	CairoPainter painter(iCascade, iFonts, cc, 1.0, false, false);
 	painter.iPdfState.push_back(ps);
 	painter.execute(pat, pat, false);
 	cairo_restore(cc);
@@ -1446,7 +1448,7 @@ void CairoPainter::drawGlyphs(std::vector<cairo_glyph_t> &glyphs)
 			  0.5);
     cairo_save(iCairo);
     cairo_set_font_matrix(iCairo, &matrix);
-    cairo_show_glyphs(iCairo, &glyphs[0], glyphs.size());
+    cairo_show_glyphs(iCairo, glyphs.data(), glyphs.size());
     cairo_restore(iCairo);
     double s = ps.iFontSize;
     cairo_set_font_size(iCairo, 0.23 * s);
@@ -1468,7 +1470,7 @@ void CairoPainter::drawGlyphs(std::vector<cairo_glyph_t> &glyphs)
     cairo_set_source_rgba(iCairo,
 			  ps.iFillRgb[0], ps.iFillRgb[1], ps.iFillRgb[2],
 			  ps.iFillOpacity);
-    cairo_show_glyphs(iCairo, &glyphs[0], glyphs.size());
+    cairo_show_glyphs(iCairo, glyphs.data(), glyphs.size());
     cairo_restore(iCairo);
   }
 }
