@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2022 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ Buffer Thumbnail::render(const Page *page, int view)
   Vector offset = - iLayout->paper().topLeft();
   cairo_translate(cc, offset.x, offset.y);
 
-  CairoPainter painter(iDoc->cascade(), iFonts.get(), cc, iZoom, true);
+  CairoPainter painter(iDoc->cascade(), iFonts.get(), cc, iZoom, true, false);
   painter.setAttributeMap(&page->viewMap(view));
   std::vector<Matrix> layerMatrices = page->layerMatrices(view);
   painter.pushMatrix();
@@ -159,7 +159,7 @@ bool Thumbnail::saveRender(TargetFormat fm, const char *dst,
   }
   cairo_translate(cc, -offset.x, -offset.y);
 
-  CairoPainter painter(iDoc->cascade(), iFonts.get(), cc, zoom, true);
+  CairoPainter painter(iDoc->cascade(), iFonts.get(), cc, zoom, true, true);
   painter.setAttributeMap(&page->viewMap(view));
   std::vector<Matrix> layerMatrices = page->layerMatrices(view);
   painter.pushMatrix();
@@ -237,7 +237,7 @@ Buffer PdfThumbnail::render(const PdfDict *page)
   cairo_scale(cc, zoom, -zoom);
 
   if (stream) {
-    CairoPainter painter(iCascade.get(), iFonts.get(), cc, 1.0, false);
+    CairoPainter painter(iCascade.get(), iFonts.get(), cc, 1.0, false, false);
     painter.executeStream(stream, page);
   }
   cairo_surface_flush(surface);
