@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2022 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -614,8 +614,6 @@ int Document::runLatexAsync(String docname, String &texLog, Latex **pConverter)
   int count = 0;
   for (int i = 0; i < countPages(); ++i)
     count = converter->scanPage(page(i));
-  if (count == 0)
-    return ErrNoText;
 
   if (iProperties.iNumberPages) {
     for (int i = 0; i < countPages(); ++i) {
@@ -623,7 +621,8 @@ int Document::runLatexAsync(String docname, String &texLog, Latex **pConverter)
       for (int j = 0; j < nviews; ++j)
 	converter->addPageNumber(i, j, countPages(), nviews);
     }
-  }
+  } else if (count == 0)
+    return ErrNoText;
 
   // First we need a directory
   String latexDir = Platform::latexDirectory();
