@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ BOOL setWindowText(HWND h, const char *s)
 {
   int rw = MultiByteToWideChar(CP_UTF8, 0, s, -1, nullptr, 0);
   std::vector<wchar_t> ws(rw);
-  MultiByteToWideChar(CP_UTF8, 0, s, -1, &ws[0], rw);
+  MultiByteToWideChar(CP_UTF8, 0, s, -1, ws.data(), rw);
   std::vector<wchar_t> w;
   for (auto ch : ws) {
     if (ch != '\r') {
@@ -63,7 +63,7 @@ BOOL setWindowText(HWND h, const char *s)
     }
   }
   w.push_back(0);
-  return SetWindowTextW(h, &w[0]);
+  return SetWindowTextW(h, w.data());
 }
 
 // --------------------------------------------------------------------
@@ -522,7 +522,7 @@ void AppUi::browseLaunch(bool launch, String dest)
 
 static const char * const aboutText =
   "IpePresenter %d.%d.%d\n\n"
-  "Copyright (c) 2020-2021 Otfried Cheong\n\n"
+  "Copyright (c) 2020-2023 Otfried Cheong\n\n"
   "A presentation tool for giving PDF presentations "
   "created in Ipe or using beamer.\n"
   "Originally invented by Dmitriy Morozov, "
@@ -546,7 +546,7 @@ static const char * const aboutText =
 void AppUi::aboutIpePresenter()
 {
   std::vector<char> buf(strlen(aboutText) + 100);
-  sprintf(&buf[0], aboutText,
+  sprintf(buf.data(), aboutText,
 	  IPELIB_VERSION / 10000,
 	  (IPELIB_VERSION / 100) % 100,
 	  IPELIB_VERSION % 100);
