@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2022 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 #include <QMenu>
 #include <QMessageBox>
 #include <QPushButton>
+#include <QRegularExpression>
 #include <QShortcut>
 #include <QSyntaxHighlighter>
 #include <QTextEdit>
@@ -98,19 +99,20 @@ class XmlHighlighter : public QSyntaxHighlighter
 public:
   XmlHighlighter(QTextEdit *textEdit);
 protected:
-  void applyFormat(const QString &text, QRegExp &exp,
+  void applyFormat(const QString &text, QRegularExpression &exp,
 		   const QTextCharFormat &format);
   virtual void highlightBlock(const QString &text);
 };
 
-void XmlHighlighter::applyFormat(const QString &text, QRegExp &exp,
+void XmlHighlighter::applyFormat(const QString &text, QRegularExpression &exp,
 				 const QTextCharFormat &format)
 {
-  int index = text.indexOf(exp);
+  QRegularExpressionMatch match;
+  int index = text.indexOf(exp, 0, &match);
   while (index >= 0) {
-    int length = exp.matchedLength();
+    int length = match.capturedLength(0);
     setFormat(index, length, format);
-    index = text.indexOf(exp, index + length);
+    index = text.indexOf(exp, index + length, &match);
   }
 }
 
@@ -123,9 +125,9 @@ void XmlHighlighter::highlightBlock(const QString &text)
   stringFormat.setForeground(dark ? Qt::cyan : Qt::darkMagenta);
   numberFormat.setForeground(Qt::red);
 
-  QRegExp tagExp( "<.*>" );
-  QRegExp stringExp( "\"[a-zA-Z]*\"" );
-  QRegExp numberExp( "[+|-]*[0-9]*.[0-9][0-9]*" );
+  QRegularExpression tagExp( "<.*>" );
+  QRegularExpression stringExp( "\"[a-zA-Z]*\"" );
+  QRegularExpression numberExp( "[+|-]*[0-9]*.[0-9][0-9]*" );
   applyFormat(text, tagExp, tagFormat);
   applyFormat(text, stringExp, stringFormat);
   applyFormat(text, numberExp, numberFormat);
@@ -144,19 +146,20 @@ class LatexHighlighter : public QSyntaxHighlighter
 public:
   LatexHighlighter(QTextEdit *textEdit);
 protected:
-  void applyFormat(const QString &text, QRegExp &exp,
+  void applyFormat(const QString &text, QRegularExpression &exp,
 		   const QTextCharFormat &format);
   virtual void highlightBlock(const QString &text);
 };
 
-void LatexHighlighter::applyFormat(const QString &text, QRegExp &exp,
+void LatexHighlighter::applyFormat(const QString &text, QRegularExpression &exp,
 				   const QTextCharFormat &format)
 {
-  int index = text.indexOf(exp);
+  QRegularExpressionMatch match;
+  int index = text.indexOf(exp, 0, &match);
   while (index >= 0) {
-    int length = exp.matchedLength();
+    int length = match.capturedLength(0);
     setFormat(index, length, format);
-    index = text.indexOf(exp, index + length);
+    index = text.indexOf(exp, index + length, &match);
   }
 }
 
@@ -168,8 +171,8 @@ void LatexHighlighter::highlightBlock(const QString &text)
   tagFormat.setFontWeight(QFont::Bold);
   tagFormat.setForeground(dark ? Qt::yellow : Qt::blue);
 
-  QRegExp mathExp( "\\$[^$]+\\$" );
-  QRegExp tagExp( "\\\\[a-zA-Z]+" );
+  QRegularExpression mathExp( "\\$[^$]+\\$" );
+  QRegularExpression tagExp( "\\\\[a-zA-Z]+" );
   applyFormat(text, mathExp, mathFormat);
   applyFormat(text, tagExp, tagFormat);
 }
