@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2023 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ BOOL setWindowText(HWND h, const char *s)
     }
   }
   w.push_back(0);
-  return SetWindowTextW(h, &w[0]);
+  return SetWindowTextW(h, w.data());
 }
 
 void sendMessage(HWND h, UINT code, const char *t, WPARAM wParam)
@@ -77,8 +77,8 @@ static std::string wideToUtf8(const wchar_t *wbuf)
 {
   int rm = WideCharToMultiByte(CP_UTF8, 0, wbuf, -1, nullptr, 0, nullptr, nullptr);
   std::vector<char> multi(rm);
-  WideCharToMultiByte(CP_UTF8, 0, wbuf, -1, &multi[0], rm, nullptr, nullptr);
-  return std::string(&multi[0]);
+  WideCharToMultiByte(CP_UTF8, 0, wbuf, -1, multi.data(), rm, nullptr, nullptr);
+  return std::string(multi.data());
 }
 
 static void buildFlags(std::vector<short> &t, DWORD flags)
@@ -275,7 +275,7 @@ static std::string getEditText(HWND h)
       w.push_back(ch);
   }
   w.push_back(0);
-  return wideToUtf8(&w[0]);
+  return wideToUtf8(w.data());
 }
 
 void PDialog::retrieveValues()
@@ -535,7 +535,7 @@ bool PDialog::buildAndRun(int w, int h)
   int res =
     DialogBoxIndirectParamW((HINSTANCE) GetWindowLongPtr(iParent,
 							 GWLP_HINSTANCE),
-			    (LPCDLGTEMPLATE) &t[0],
+			    (LPCDLGTEMPLATE) t.data(),
 			    iParent, (DLGPROC) dialogProc, (LPARAM) this);
   // retrieveValues() has been called before EndDialog!
   hDialog = nullptr; // already destroyed by Windows
@@ -1040,7 +1040,7 @@ static int ipeui_fileDialog(lua_State *L)
   ofn.lStructSize = sizeof(ofn);
   ofn.hwndOwner = hwnd;
 
-  ofn.lpstrFilter = &filters[0];
+  ofn.lpstrFilter = filters.data();
   ofn.nFilterIndex = selected;
 
   ofn.lpstrFile = szFileName;
@@ -1268,7 +1268,7 @@ static int ipeui_wait(lua_State *L)
 				INFINITE, WT_EXECUTEINWAITTHREAD|WT_EXECUTEONLYONCE);
 
     DialogBoxIndirectParamW((HINSTANCE) GetWindowLongPtr(parent, GWLP_HINSTANCE),
-			    (LPCDLGTEMPLATE) &t[0],
+			    (LPCDLGTEMPLATE) t.data(),
 			    parent, (DLGPROC) waitDialogProc,
 			    (LPARAM) &dialogHandle);
 
@@ -1289,7 +1289,7 @@ static int ipeui_wait(lua_State *L)
     lua_pushvalue(L, 2);
 
     DialogBoxIndirectParamW((HINSTANCE) GetWindowLongPtr(parent, GWLP_HINSTANCE),
-			    (LPCDLGTEMPLATE) &t[0],
+			    (LPCDLGTEMPLATE) t.data(),
 			    parent, (DLGPROC) waitDialogProc,
 			    (LPARAM) &dialogHandle);
     UnregisterWait(waitHandle);
